@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp 1314 2008-02-25 22:53:26Z vaclavslavik $
+ *  $Id$
  *
  *  Translations catalog
  *
@@ -76,14 +76,44 @@ static wxString ReadTextLine(wxTextFile* f)
 
 // If input begins with pattern, fill output with end of input (without
 // pattern; strips trailing spaces) and return true.  Return false otherwise
-// and don't touch output
+// and don't touch output. Is permissive about whitespace in the input:
+// a space (' ') in pattern will match any number of any whitespace characters
+// on that position in input.
 static bool ReadParam(const wxString& input, const wxString& pattern, wxString& output)
 {
-    if (input.Length() < pattern.Length()) return false;
+    if (input.size() < pattern.size())
+        return false;
 
-    for (unsigned i = 0; i < pattern.Length(); i++)
-        if (input[i] != pattern[i]) return false;
-    output = input.Mid(pattern.Length()).Strip(wxString::trailing);
+    unsigned in_pos = 0;
+    unsigned pat_pos = 0;
+    while (pat_pos < pattern.size() && in_pos < input.size())
+    {
+        const wxChar pat = pattern[pat_pos++];
+
+        if (pat == _T(' '))
+        {
+            if (!wxIsspace(input[in_pos++]))
+                return false;
+
+            while (wxIsspace(input[in_pos]))
+            {
+                in_pos++;
+                if (in_pos == input.size())
+                    return false;
+            }
+        }
+        else
+        {
+            if (input[in_pos++] != pat)
+                return false;
+        }
+
+    }
+
+    if (pat_pos < pattern.size()) // pattern not fully matched
+        return false;
+
+    output = input.Mid(in_pos).Strip(wxString::trailing);
     return true;
 }
 
@@ -162,6 +192,10 @@ static wxString UnescapeCEscapes(const wxString& str)
                     out << _T('\\');
                     i++;
                     break;
+                case _T('"'):
+                    out << _T('"');
+                    i++;
+                    break;
                 default:
                     out << _T('\\');
             }
@@ -225,6 +259,7 @@ wxString Catalog::HeaderData::ToString(const wxString& line_delim)
     {
         wxString v(i->Value);
         v.Replace(_T("\\"), _T("\\\\"));
+        v.Replace(_T("\""), _T("\\\""));
         hdr << i->Key << _T(": ") << v << _T("\\n") << line_delim;
     }
     return hdr;
@@ -560,8 +595,7 @@ bool CatalogParser::Parse()
         }
 
         // msgctxt:
-        else if (ReadParam(line, _T("msgctxt \""), dummy) ||
-                 ReadParam(line, _T("msgctxt\t\""), dummy))
+        else if (ReadParam(line, _T("msgctxt \""), dummy))
         {
             has_context = true;
             msgctxt = dummy.RemoveLast();
@@ -577,8 +611,7 @@ bool CatalogParser::Parse()
         }
 
         // msgid:
-        else if (ReadParam(line, _T("msgid \""), dummy) ||
-                 ReadParam(line, _T("msgid\t\""), dummy))
+        else if (ReadParam(line, _T("msgid \""), dummy))
         {
             mstr = dummy.RemoveLast();
             mlinenum = m_textFile->GetCurrentLine() + 1;
@@ -594,8 +627,7 @@ bool CatalogParser::Parse()
         }
 
         // msgid_plural:
-        else if (ReadParam(line, _T("msgid_plural \""), dummy) ||
-                 ReadParam(line, _T("msgid_plural\t\""), dummy))
+        else if (ReadParam(line, _T("msgid_plural \""), dummy))
         {
             msgid_plural = dummy.RemoveLast();
             has_plural = true;
@@ -612,8 +644,7 @@ bool CatalogParser::Parse()
         }
 
         // msgstr:
-        else if (ReadParam(line, _T("msgstr \""), dummy) ||
-                 ReadParam(line, _T("msgstr\t\""), dummy))
+        else if (ReadParam(line, _T("msgstr \""), dummy))
         {
             if (has_plural)
             {
@@ -662,15 +693,13 @@ bool CatalogParser::Parse()
             wxString idx = dummy.BeforeFirst(_T(']'));
             wxString label = _T("msgstr[") + idx + _T("]");
 
-            while (ReadParam(line, label + _T(" \""), dummy) ||
-                   ReadParam(line, label + _T("\t\""), dummy))
+            while (ReadParam(line, label + _T(" \""), dummy))
             {
                 wxString str = dummy.RemoveLast();
 
                 while (!(line=ReadTextLine(m_textFile)).empty())
                 {
-                    if (line[0u] == _T('\t'))
-                        line.Remove(0, 1);
+                    line.Trim(/*fromRight=*/false);
                     if (line[0u] == _T('"') && line.Last() == _T('"'))
                         str += line.Mid(1, line.Length() - 2);
                     else
@@ -714,6 +743,10 @@ bool CatalogParser::Parse()
                 // if line does not start with "#~ " anymore, stop reading
                 if (!ReadParam(line, _T("#~ "), dummy))
                     break;
+                // if the line starts with "#~ msgid", we skipped an empty line
+                // and it's a new entry, so stop reading too (see bug #329)
+                if (ReadParam(line, _T("#~ msgid"), dummy))
+                    break;
 
                 deletedLines.Add(line);
             }
@@ -750,7 +783,9 @@ bool CatalogParser::Parse()
         }
 
         else
+        {
             line = ReadTextLine(m_textFile);
+        }
     }
 
     return true;
@@ -941,7 +976,7 @@ void Catalog::CreateNewHeader()
     dt.Project = wxEmptyString;
     dt.Team = wxEmptyString;
     dt.TeamEmail = wxEmptyString;
-    dt.Charset = _T("utf-8");
+    dt.Charset = _T("UTF-8");
     dt.Translator = wxConfig::Get()->Read(_T("translator_name"), wxEmptyString);
     dt.TranslatorEmail = wxConfig::Get()->Read(_T("translator_email"), wxEmptyString);
     dt.SourceCodeCharset = wxEmptyString;
@@ -956,6 +991,27 @@ void Catalog::CreateNewHeader()
     dt.UpdateDict();
 }
 
+void Catalog::CreateNewHeader(const Catalog::HeaderData& pot_header)
+{
+    HeaderData &dt = Header();
+    dt = pot_header;
+
+    // UTF-8 should be used by default no matter what the POT uses
+    dt.Charset = _T("UTF-8");
+
+    // clear the fields that are translation-specific:
+    dt.Language.clear();
+    dt.Country.clear();
+    dt.Team.clear();
+    dt.TeamEmail.clear();
+
+    // translator should be pre-filled
+    dt.Translator = wxConfig::Get()->Read(_T("translator_name"), wxEmptyString);
+    dt.TranslatorEmail = wxConfig::Get()->Read(_T("translator_email"), wxEmptyString);
+
+    dt.UpdateDict();
+}
+
 
 bool Catalog::Load(const wxString& po_file)
 {
@@ -1134,7 +1190,7 @@ static bool CanEncodeStringToCharset(const wxString& s, wxMBConv& conv)
 
 static bool CanEncodeToCharset(Catalog& catalog, const wxString& charset)
 {
-    if (charset == _T("utf-8") || charset == _T("UTF-8"))
+    if (charset.Lower() == _T("utf-8") || charset.Lower() == _T("utf8"))
         return true;
 
     wxCSConv conv(charset);
@@ -1260,7 +1316,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
 
     wxString charset(m_header.Charset);
     if (!charset || charset == _T("CHARSET"))
-        charset = _T("utf-8");
+        charset = _T("UTF-8");
 
     if (!CanEncodeToCharset(*this, charset))
     {
@@ -1268,7 +1324,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
         msg.Printf(_("The catalog couldn't be saved in '%s' charset as\nspecified in catalog settings. It was saved in UTF-8 instead\nand the setting was modified accordingly."), charset.c_str());
         wxMessageBox(msg, _("Error saving catalog"),
                      wxOK | wxICON_EXCLAMATION);
-        charset = _T("utf-8");
+        charset = _T("UTF-8");
     }
     m_header.Charset = charset;
 
@@ -1337,6 +1393,9 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     // Write back deleted items in the file so that they're not lost
     for (unsigned i = 0; i < m_deletedItems.size(); i++)
     {
+        if ( i != 0 )
+            f.AddLine(wxEmptyString);
+
         CatalogDeletedData& deletedItem = m_deletedItems[i];
         SaveMultiLines(f, deletedItem.GetComment());
         for (unsigned i = 0; i < deletedItem.GetAutoComments().GetCount(); i++)
@@ -1350,8 +1409,6 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
 
         for (size_t j = 0; j < deletedItem.GetDeletedLines().GetCount(); j++)
             f.AddLine(deletedItem.GetDeletedLines()[j]);
-
-        f.AddLine(wxEmptyString);
     }
 
 
@@ -1442,7 +1499,8 @@ bool Catalog::Update(bool summary)
 }
 
 
-bool Catalog::UpdateFromPOT(const wxString& pot_file, bool summary)
+bool Catalog::UpdateFromPOT(const wxString& pot_file, bool summary,
+                            bool replace_header)
 {
     if (!m_isOk) return false;
 
@@ -1455,9 +1513,17 @@ bool Catalog::UpdateFromPOT(const wxString& pot_file, bool summary)
     }
 
     if (!summary || ShowMergeSummary(&newcat))
-        return Merge(&newcat);
+    {
+        if ( !Merge(&newcat) )
+            return false;
+        if ( replace_header )
+            CreateNewHeader(newcat.Header());
+        return true;
+    }
     else
+    {
         return false;
+    }
 }
 
 
