@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.h 1313 2008-02-25 12:07:41Z vaclavslavik $
+ *  $Id$
  *
  *  Translations catalog
  *
@@ -469,6 +469,10 @@ class Catalog
          */
         void CreateNewHeader();
 
+        /** Creates new header initialized based on a POT file's header.
+         */
+        void CreateNewHeader(const HeaderData& pot_header);
+
         /// Clears the catalog, removes all entries from it.
         void Clear();
 
@@ -502,7 +506,9 @@ class Catalog
         /** Updates the catalog from POT file.
             \see Update
          */
-        bool UpdateFromPOT(const wxString& pot_file, bool summary = true);
+        bool UpdateFromPOT(const wxString& pot_file,
+                           bool summary = true,
+                           bool replace_header = false);
 
         /// Returns the number of strings/translations in the catalog.
         size_t GetCount() const { return m_items.size(); }
