@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: chooselang.cpp 1357 2008-03-03 22:23:37Z vaclavslavik $
+ *  $Id$
  *
  *  Language chooser
  *
@@ -68,7 +68,7 @@ wxLanguage GetUILanguage()
         if (info != NULL)
             lang = (wxLanguage)info->Language;
         else
-            wxLogError(_("Uknown locale code '%s' in registry."), lng.c_str());
+            wxLogError(_("Unknown locale code '%s' in registry."), lng.c_str());
     }
     return lang;
 #endif // NEED_CHOOSELANG_UI
@@ -121,6 +121,7 @@ wxLanguage ChooseLanguage()
         { _T("Irish"), wxLANGUAGE_IRISH },
         { _T("Italian"), wxLANGUAGE_ITALIAN },
         { _T("Japanese"), wxLANGUAGE_JAPANESE },
+        { _T("Kazakh"), wxLANGUAGE_KAZAKH },
         { _T("Korean"), wxLANGUAGE_KOREAN },
         { _T("Kurdish"), wxLANGUAGE_KURDISH },
         { _T("Kyrgyz"), wxLANGUAGE_KIRGHIZ },
@@ -138,6 +139,7 @@ wxLanguage ChooseLanguage()
         { _T("Romanian"), wxLANGUAGE_ROMANIAN },
         { _T("Russian"), wxLANGUAGE_RUSSIAN },
         { _T("Serbian"), wxLANGUAGE_SERBIAN },
+        { _T("Serbian (Latin)"), wxLANGUAGE_SERBIAN_LATIN },
         { _T("Slovak"), wxLANGUAGE_SLOVAK },
         { _T("Slovenian"), wxLANGUAGE_SLOVENIAN },
         { _T("Spanish"), wxLANGUAGE_SPANISH },
@@ -149,6 +151,9 @@ wxLanguage ChooseLanguage()
         { _T("Turkish"), wxLANGUAGE_TURKISH },
         { _T("Ukrainian"), wxLANGUAGE_UKRAINIAN },
         { _T("Urdu"), wxLANGUAGE_URDU },
+        { _T("Uyghur"), wxLANGUAGE_UIGHUR },
+        { _T("Uzbek"), wxLANGUAGE_UZBEK },
+        { _T("Vietnamese"), wxLANGUAGE_VIETNAMESE },
         { _T(""), wxLANGUAGE_UNKNOWN }
     };
 
