@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2008 Vaclav Slavik
+ *  Copyright (C) 1999-2010 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edapp.cpp 1449 2008-08-11 21:08:43Z vaclavslavik $
+ *  $Id$
  *
  *  Application class
  *
@@ -43,8 +43,13 @@
 
 #ifdef USE_SPARKLE
 #include <Sparkle/SUCarbonAPI.h>
+#include "osx/userdefaults.h"
 #endif // USE_SPARKLE
 
+#ifdef __WXMSW__
+#include <winsparkle.h>
+#endif
+
 #if !wxUSE_UNICODE
     #error "Unicode build of wxWidgets is required by Poedit"
 #endif
@@ -56,6 +61,7 @@
 #include "parser.h"
 #include "chooselang.h"
 #include "icons.h"
+#include "version.h"
 
 
 IMPLEMENT_APP(PoeditApp);
@@ -81,8 +87,7 @@ wxString PoeditApp::GetAppPath() const
 
 wxString PoeditApp::GetAppVersion() const
 {
-    wxString version(_T("1.4.2"));
-    return version;
+    return wxString::FromAscii(POEDIT_VERSION);
 }
 
 
@@ -196,12 +201,29 @@ bool PoeditApp::OnInit()
 #endif // !__WXMAC__
 
 #ifdef USE_SPARKLE
+    // Remove config key for Sparkle < 1.5.
+    UserDefaults::RemoveValue("SUCheckAtStartup");
+
     SUSparkleInitializeForCarbon();
 #endif // USE_SPARKLE
 
+#ifdef __WXMSW__
+    win_sparkle_set_appcast_url("http://releases.poedit.net/appcast_win.xml");
+    win_sparkle_init();
+#endif
+
     return true;
 }
 
+int PoeditApp::OnExit()
+{
+#ifdef __WXMSW__
+    win_sparkle_cleanup();
+#endif
+
+    return wxApp::OnExit();
+}
+
 
 void PoeditApp::OpenNewFile()
 {
