@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edapp.h 1175 2007-10-03 06:38:00Z vaclavslavik $
+ *  $Id$
  *
  *  Editor application object
  *
@@ -45,7 +45,8 @@ class PoeditApp : public wxApp
         /** wxWin initalization hook. Shows PoeditFrame and initializes
             configuration entries to default values if they were missing.
          */
-        bool OnInit();
+        virtual bool OnInit();
+        virtual int OnExit();
 
         /** Gets application's path. This path is used when looking for 
             resources.zip and help files, both of them can be found
