@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 1999-2008 Vaclav Slavik
+ *  Copyright (C) 1999-2009 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: edframe.cpp 1450 2008-08-12 16:53:24Z vaclavslavik $
+ *  $Id$
  *
  *  Editor frame
  *
@@ -829,23 +829,30 @@ static void DoInitSpellchecker(wxTextCtrl *text,
     wxASSERT_MSG( textview, _T("wxTextCtrl is supposed to use GtkTextView") );
     GtkSpell *spell = gtkspell_get_from_text_view(textview);
 
-    if (spell)
-        gtkspell_detach(spell);
+    GError *err = NULL;
 
     if (enable)
     {
-        GError *err = NULL;
-        if (!gtkspell_new_attach(textview, lang.ToAscii(), &err))
-        {
-#if 0
-            // FIXME: report the failure in some less intrusive way than the
-            //        code that was used here; say for which language, too
-            wxLogError(_("Error initializing spell checking: %s"),
-                       wxString(err->message, wxConvUTF8).c_str());
-#endif
-            g_error_free(err);
-        }
+        if (spell)
+            gtkspell_set_language(spell, lang.ToAscii(), &err);
+        else
+            gtkspell_new_attach(textview, lang.ToAscii(), &err) != NULL;
     }
+    else // !enable
+    {
+        // GtkSpell when used with Zemberek Enchant module doesn't work
+        // correctly if you repeatedly attach and detach a speller to text
+        // view. See http://www.poedit.net/trac/ticket/276 for details.
+        //
+        // To work around this, we set the language to a non-existent one
+        // instead of detaching GtkSpell -- this has the same effect as
+        // detaching the speller as far as the UI is concerned.
+        if (spell)
+            gtkspell_set_language(spell, "unknown_language", &err);
+    }
+
+    if (err)
+        g_error_free(err);
 }
 #endif // __WXGTK__
 
@@ -1226,7 +1233,9 @@ void PoeditFrame::OnNew(wxCommandEvent& event)
         if (!pot_file.empty())
         {
             wxConfig::Get()->Write(_T("last_file_path"), wxPathOnly(pot_file));
-            ok = catalog->UpdateFromPOT(pot_file, false/*summary*/);
+            ok = catalog->UpdateFromPOT(pot_file,
+                                        /*summary=*/false,
+                                        /*replace_header=*/true);
         }
         if (!ok)
         {
@@ -1234,6 +1243,10 @@ void PoeditFrame::OnNew(wxCommandEvent& event)
             return;
         }
     }
+    else
+    {
+        catalog->CreateNewHeader();
+    }
 
     dlg.TransferTo(catalog);
     if (dlg.ShowModal() == wxID_OK)
@@ -2074,12 +2087,27 @@ bool PoeditFrame::WriteCatalog(const wxString& catalog)
         size_t cnt = m_catalog->GetCount();
         for (size_t i = 0; i < cnt; i++)
         {
-            CatalogItem& dt = (*m_catalog)[i];
-            if (dt.IsModified() && !dt.IsFuzzy() &&
-                dt.GetValidity() == CatalogItem::Val_Valid &&
-                !dt.GetTranslation().empty())
+            const CatalogItem& dt = (*m_catalog)[i];
+
+            // ignore translations with errors in them
+            if (dt.GetValidity() == CatalogItem::Val_Invalid)
+                continue;
+
+            // ignore untranslated or unfinished translations
+            if (dt.IsFuzzy() || dt.GetTranslation().empty())
+                continue;
+
+            // Note that dt.IsModified() is intentionally not checked - we
+            // want to save old entries in the TM too, so that we harvest as
+            // much useful translations as we can.
+
+            if ( !tm->Store(dt.GetString(), dt.GetTranslation()) )
             {
-                tm->Store(dt.GetString(), dt.GetTranslation());
+                // If the TM failed, it would almost certainly fail to store
+                // the next item as well. Don't bother, just stop updating
+                // it here, so that the user is given only one error message
+                // instead of an insane amount of them.
+                break;
             }
         }
     }
@@ -2267,7 +2295,7 @@ void PoeditFrame::OnAbout(wxCommandEvent&)
     about.SetName(_T("Poedit"));
     about.SetVersion(wxGetApp().GetAppVersion());
     about.SetDescription(_("Poedit is an easy to use translations editor."));
-    about.SetCopyright(_T("Copyright \u00a9 1999-2008 Vaclav Slavik"));
+    about.SetCopyright(_T("Copyright \u00a9 1999-2010 Vaclav Slavik"));
 #ifdef __WXGTK__ // other ports would show non-native about dlg
     about.SetWebSite(_T("http://www.poedit.net"));
 #endif
@@ -2688,6 +2716,11 @@ void PoeditFrame::RecreatePluralTextCtrls()
             m_textTransSingularForm = txt;
     }
 
+    // as a fallback, assume 1st form for plural entries is the singular
+    // (like in English and most real-life uses):
+    if (!m_textTransSingularForm && !m_textTransPlural.empty())
+        m_textTransSingularForm = m_textTransPlural[0];
+
     delete calc;
 
     SetCustomFonts();
