@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.cpp 1358 2008-03-04 10:40:09Z vaclavslavik $
+ *  $Id$
  *
  *  List view control
  *
@@ -224,9 +224,25 @@ PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
 
     wxVisualAttributes visual = GetDefaultAttributes();
     wxColour shaded = visual.colBg;
-    shaded.Set(int(DARKEN_FACTOR * shaded.Red()),
-               int(DARKEN_FACTOR * shaded.Green()),
-               int(DARKEN_FACTOR * shaded.Blue()));
+
+#ifdef __WXMSW__
+    // On Windows 7, shaded list items make it impossible to see the selection,
+    // so use different color for it (see bug #336).
+    int verMaj, verMin;
+    wxGetOsVersion(&verMaj, &verMin);
+    if ( verMaj > 6 || (verMaj == 6 && verMin >= 1) )
+    {
+        shaded.Set(int(0.99 * shaded.Red()),
+                   int(0.99 * shaded.Green()),
+                   shaded.Blue());
+    }
+    else
+#endif // __WXMSW__
+    {
+        shaded.Set(int(DARKEN_FACTOR * shaded.Red()),
+                   int(DARKEN_FACTOR * shaded.Green()),
+                   int(DARKEN_FACTOR * shaded.Blue()));
+    }
 
     m_attrNormal[1].SetBackgroundColour(shaded);
     m_attrUntranslated[1].SetBackgroundColour(shaded);
