@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: findframe.cpp 1395 2008-04-05 13:17:06Z vaclavslavik $
+ *  $Id$
  *
  *  Search frame
  *
@@ -296,11 +296,13 @@ bool FindFrame::DoFind(int dir)
 
     if (found != Found_Not)
     {
+        m_listCtrl->EnsureVisible(m_position);
+#ifdef __WXMAC__
+        m_listCtrl->Refresh();
+#endif
+        m_listCtrl->Select(m_position);
         m_listCtrl->SetItemState(m_position,
                     wxLIST_STATE_FOCUSED, wxLIST_STATE_FOCUSED);
-        m_listCtrl->SetItemState(m_position,
-                    wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
-        m_listCtrl->EnsureVisible(m_position);
 
         // find the text on the control and select it:
 
